@@ -61,11 +61,67 @@ testing_extension_test_teardown_ (TestingExtensionFixture_ *fixture,
 
 void
 testing_extension_test_runner_  (TestingExtensionFixture_ *fixture,
-                               gconstpointer             data)
+                                 gconstpointer             data)
 {
   ((void (*) (PeasEngine *engine)) data) (fixture->engine);
 }
 
+void
+testing_extension_garbage_collect_ (PeasEngine *engine)
+{
+  PeasPluginInfo *info;
+
+  info = peas_engine_get_plugin_info (engine, extension_plugin);
+
+  /* See that we can collect the garbage when no plugins are loaded */
+  peas_engine_garbage_collect (engine);
+
+  g_assert (peas_engine_load_plugin (engine, info));
+
+  peas_engine_garbage_collect (engine);
+}
+
+void
+testing_extension_provides_valid_ (PeasEngine *engine)
+{
+  PeasPluginInfo *info;
+
+  info = peas_engine_get_plugin_info (engine, extension_plugin);
+
+  g_assert (peas_engine_load_plugin (engine, info));
+
+  g_assert (peas_engine_provides_extension (engine, info,
+                                            INTROSPECTION_TYPE_CALLABLE));
+}
+
+void
+testing_extension_provides_invalid_ (PeasEngine *engine)
+{
+  PeasPluginInfo *info;
+
+  testing_util_push_log_hook ("*assertion `G_TYPE_IS_INTERFACE (*)' failed");
+
+  info = peas_engine_get_plugin_info (engine, extension_plugin);
+
+  /* Not loaded */
+  g_assert (!peas_engine_provides_extension (engine, info,
+                                             INTROSPECTION_TYPE_CALLABLE));
+
+  g_assert (peas_engine_load_plugin (engine, info));
+
+  /* Invalid GType */
+  peas_engine_provides_extension (engine, info, G_TYPE_INVALID);
+
+
+  /* GObject but not a GInterface */
+  peas_engine_provides_extension (engine, info, PEAS_TYPE_ENGINE);
+
+
+  /* Does not implement this GType */
+  g_assert (!peas_engine_provides_extension (engine, info,
+                                             INTROSPECTION_TYPE_UNIMPLEMENTED));
+}
+
 void
 testing_extension_create_valid_ (PeasEngine *engine)
 {
@@ -92,34 +148,28 @@ testing_extension_create_invalid_ (PeasEngine *engine)
   PeasPluginInfo *info;
   PeasExtension *extension;
 
+  testing_util_push_log_hook ("*assertion `peas_plugin_info_is_loaded (*)' failed");
+  testing_util_push_log_hook ("*assertion `G_TYPE_IS_INTERFACE (*)' failed");
+  testing_util_push_log_hook ("*does not provide a 'IntrospectionUnimplemented' extension");
+  testing_util_push_log_hook ("*type 'IntrospectionCallable' has no property named 'invalid-property'");
+
   info = peas_engine_get_plugin_info (engine, extension_plugin);
 
   /* Not loaded */
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-    {
-      peas_engine_create_extension (engine, info,
-                                    INTROSPECTION_TYPE_CALLABLE,
-                                    NULL);
-      exit (0);
-    }
-  g_test_trap_assert_failed ();
+  extension = peas_engine_create_extension (engine, info,
+                                            INTROSPECTION_TYPE_CALLABLE,
+                                            NULL);
+  g_assert (!PEAS_IS_EXTENSION (extension));
 
   g_assert (peas_engine_load_plugin (engine, info));
 
   /* Invalid GType */
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-    {
-      peas_engine_create_extension (engine, info, G_TYPE_INVALID, NULL);
-      exit (0);
-    }
-  g_test_trap_assert_failed ();
-  g_test_trap_assert_stderr ("*CRITICAL*");
+  extension = peas_engine_create_extension (engine, info, G_TYPE_INVALID, NULL);
+  g_assert (!PEAS_IS_EXTENSION (extension));
 
 
   /* GObject but not a GInterface */
-  extension = peas_engine_create_extension (engine, info,
-                                            PEAS_TYPE_ENGINE,
-                                            NULL);
+  extension = peas_engine_create_extension (engine, info, PEAS_TYPE_ENGINE, NULL);
   g_assert (!PEAS_IS_EXTENSION (extension));
 
 
@@ -128,6 +178,13 @@ testing_extension_create_invalid_ (PeasEngine *engine)
                                             INTROSPECTION_TYPE_UNIMPLEMENTED,
                                             NULL);
   g_assert (!PEAS_IS_EXTENSION (extension));
+
+  /* Interface does not have an 'invalid-property' property */
+  extension = peas_engine_create_extension (engine, info,
+                                            INTROSPECTION_TYPE_CALLABLE,
+                                            "invalid-property", "does-not-exist",
+                                            NULL);
+  g_assert (!PEAS_IS_EXTENSION (extension));
 }
 
 void
@@ -145,31 +202,6 @@ testing_extension_reload_ (PeasEngine *engine)
     }
 }
 
-void
-testing_extension_call_invalid_ (PeasEngine *engine)
-{
-  PeasPluginInfo *info;
-  PeasExtension *extension;
-
-  info = peas_engine_get_plugin_info (engine, extension_plugin);
-
-  g_assert (peas_engine_load_plugin (engine, info));
-
-  extension = peas_engine_create_extension (engine, info,
-                                            INTROSPECTION_TYPE_CALLABLE,
-                                            NULL);
-
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-    {
-      peas_extension_call (extension, "invalid", NULL);
-      exit (0);
-    }
-  g_test_trap_assert_failed ();
-  g_test_trap_assert_stderr ("*Method 'IntrospectionCallable.invalid' not found*");
-
-  g_object_unref (extension);
-}
-
 void
 testing_extension_call_no_args_ (PeasEngine *engine)
 {
@@ -291,32 +323,17 @@ testing_extension_properties_construct_only_ (PeasEngine *engine)
 
   info = peas_engine_get_plugin_info (engine, extension_plugin);
 
-  FILE *saved_stdout = stdout;
-  FILE *saved_stderr = stderr;
-
   g_assert (peas_engine_load_plugin (engine, info));
 
-  stdout = saved_stdout;
-  stderr = saved_stderr;
-
   extension = peas_engine_create_extension (engine, info,
                                             INTROSPECTION_TYPE_PROPERTIES,
                                             "construct-only", "my-construct-only",
                                             NULL);
 
-
   g_object_get (extension, "construct-only", &construct_only, NULL);
   g_assert_cmpstr (construct_only, ==, "my-construct-only");
   g_free (construct_only);
 
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-    {
-      g_object_set (extension, "construct-only", "other-construct-only", NULL);
-      exit (0);
-    }
-  g_test_trap_assert_failed ();
-  g_test_trap_assert_stderr ("*WARNING*");
-
   g_object_unref (extension);
 }
 
@@ -339,14 +356,6 @@ testing_extension_properties_read_only_ (PeasEngine *engine)
   g_assert_cmpstr (read_only, ==, "read-only");
   g_free (read_only);
 
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-    {
-      g_object_set (extension, "read-only", "my-read-only", NULL);
-      exit (0);
-    }
-  g_test_trap_assert_failed ();
-  g_test_trap_assert_stderr ("*WARNING*");
-
   g_object_unref (extension);
 }
 
@@ -364,16 +373,6 @@ testing_extension_properties_write_only_ (PeasEngine *engine)
                                             INTROSPECTION_TYPE_PROPERTIES,
                                             NULL);
 
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-    {
-      gchar *write_only = NULL;
-
-      g_object_get (extension, "write-only", &write_only, NULL);
-      exit (0);
-    }
-  g_test_trap_assert_failed ();
-  g_test_trap_assert_stderr ("*WARNING*");
-
   g_object_set (extension, "write-only", "my-write-only", NULL);
 
   g_object_unref (extension);
